@@ -1,11 +1,10 @@
 # SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
 # SPDX-License-Identifier: MIT
 
-from board import SCL, SDA
-import busio
+import board
 from adafruit_apds9960.apds9960 import APDS9960
 
-i2c = busio.I2C(SCL, SDA)
+i2c = board.I2C()
 
 apds = APDS9960(i2c)
 apds.enable_proximity = True
